@@ -28,16 +28,18 @@ class KLineEdit;
 class KActionMenu;
 class ScriptManager;
 
+// Models around the Collection / KEduVocDocument
+class LessonModel;
+class VocabularyModel;
+class VocabularyFilter;
+class WordClassModel;
+
 namespace Editor
 {
 class VocabularyView;
-class VocabularyModel;
-class VocabularyFilter;
 class LessonView;
 class WordTypeView;
 class LeitnerView;
-class LessonModel;
-class WordTypeModel;
 class LeitnerModel;
 class InflectionWidget;
 class ComparisonWidget;
@@ -139,8 +141,8 @@ private:
     LessonView *m_lessonView;
     LessonModel *m_lessonModel;
 
+    WordClassModel *m_wordTypeModel;
     WordTypeView *m_wordTypeView;
-    WordTypeModel *m_wordTypeModel;
 
     LeitnerView *m_leitnerView;
     LeitnerModel *m_leitnerModel;
