@@ -12,8 +12,8 @@
  ***************************************************************************/
 #include "latexwidget.h"
 
-#include "vocabulary/vocabularymodel.h"
-#include "vocabulary/vocabularyfilter.h"
+#include "vocabularymodel.h"
+#include "vocabularyfilter.h"
 #include "practice/latexrenderer.h"
 
 #include <QDataWidgetMapper>
