@@ -12,13 +12,15 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
 #include "summarywordwidget.h"
 
 #include "languagesettings.h"
-#include "vocabulary/lessonmodel.h"
-#include "vocabulary/vocabularymodel.h"
-#include "vocabulary/vocabularyfilter.h"
-#include "vocabulary/wordtypemodel.h"
+
+#include "lessonmodel.h"
+#include "vocabularymodel.h"
+#include "vocabularyfilter.h"
+#include "wordclassmodel.h"
 
 // Qt headers
 #include <QAbstractItemModel>
@@ -29,15 +31,18 @@
 #include <QTreeView>
 
 // KDE imports
+#include <KIcon>
+#include <KLocale>
+
+// KEduVocDocument
 #include <keduvoccontainer.h>
 #include <keduvocdocument.h>
 #include <keduvocexpression.h>
 #include <keduvocwordtype.h>
-#include <KIcon>
-#include <KLocale>
 
 using namespace Editor;
 
+
 SummaryWordWidget::SummaryWordWidget(VocabularyFilter *model, KEduVocDocument *doc, QWidget *parent)
     : QWidget(parent)
     , m_doc(doc)
@@ -102,7 +107,7 @@ void SummaryWordWidget::slotDocumentChanged(KEduVocDocument *doc)
         delete m_wordTypeView;
         if (!m_wordTypeModel) {
             kDebug() << "Create word type model for summary view";
-            m_wordTypeModel = new WordTypeModel(this);
+            m_wordTypeModel = new WordClassModel(this);
         }
         m_wordTypeModel->setDocument(m_doc);
         m_wordTypeView = new QTreeView(this);
@@ -192,7 +197,7 @@ void SummaryWordDelegate::setEditorData(QWidget *editor, const QModelIndex &inde
 
     if (editor) {
         switch (VocabularyModel::columnType(index.column())) {
-        case VocabularyModel::WordType:
+        case VocabularyModel::WordClass:
             break;
 
         case VocabularyModel::Comment:
