@@ -34,39 +34,9 @@
 
 #include <QPointer>
 
-namespace Practice
-{
-class GuiFrontend;
-class DefaultBackend;
-class PracticeSummaryComponent;
-}
-
-namespace Editor
-{
-class VocabularyView;
-class VocabularyModel;
-class VocabularyFilter;
-class LessonView;
-class WordTypeView;
-class LeitnerView;
-class LessonModel;
-class WordTypeModel;
-class LeitnerModel;
-class ConjugationWidget;
-class SummaryWordWidget;
-class EditorWindow;
-}
 
 class KRecentFilesAction;
-class KActionMenu;
-class KAction;
-class QLabel;
-class QDockWidget;
 
-class WelcomeScreen;
-class StatisticsMainWindow;
-class ScriptManager;
-class ParleyPracticeMainWindow;
 
 class ParleyMainWindow : public KXmlGuiWindow
 {
@@ -80,7 +50,7 @@ public:
     /** enum for the different components that can be displayed */
     enum Component {
         NoComponent,
-        WelcomeComponent,
+        DashboardComponent,
         EditorComponent,
         ConfigurePracticeComponent,
         PracticeComponent,
@@ -101,7 +71,7 @@ public:
     /** This will look at the lesson list and also the combo box to determine what should be displayed in the table. */
     void updateTableFilter();
 
-    /** update the list of recent files in the welcome screen */
+    /** update the list of recent files in the dashboard */
     void updateRecentFilesModel();
 
     /**
@@ -153,7 +123,7 @@ public slots:
      */
     void startupTipOfDay();
 
-    void showWelcomeScreen();
+    void showDashboard();
     void showEditor();
     void showPractice();
     void showPracticeConfiguration();
