@@ -16,7 +16,7 @@
 #define MULTIPLECHOICEBACKENDMODE_H
 
 #include "abstractbackendmode.h"
-#include "practice/testentrymanager.h"
+#include "practice/sessionmanagerbase.h"
 
 namespace Practice
 {
@@ -26,8 +26,10 @@ class MultipleChoiceBackendMode : public AbstractBackendMode
     Q_OBJECT
 
 public:
-    MultipleChoiceBackendMode(const PracticeOptions& PracticeOptions, AbstractFrontend *frontend, QObject *parent, Practice::TestEntryManager* testEntryManager);
+    MultipleChoiceBackendMode(AbstractFrontend *frontend, QObject *parent,
+                              Practice::SessionManagerBase* sessionManager);
 
+    /** Start practicing a new word */
     virtual bool setTestEntry(TestEntry* current);
 
     virtual void checkAnswer();
@@ -58,8 +60,13 @@ protected:
 
     int numberOfChoices();
 
+    /**
+     * Configure the multiple choice front end.
+     */
+    virtual void populateFrontEnd();
+
 private:
-    TestEntryManager* m_testEntryManager;
+    SessionManagerBase* m_sessionManager;
     KRandomSequence m_randomSequence;
     QString m_question;
     int m_numberOfChoices;
