@@ -16,8 +16,8 @@
 #include "parley.h"
 
 #include "editor/editor.h"
-#include "../../vocabulary/vocabularymodel.h"
-#include "../../vocabulary/vocabularyview.h"
+#include "vocabularymodel.h"
+#include "vocabularyview.h"
 
 #include "../scriptmanager.h"
 #include "../translator.h"
