@@ -14,9 +14,11 @@
  ***************************************************************************/
 
 #include "statisticsmodel.h"
+#include "statisticslegendwidget.h"
 
 #include <KLocalizedString>
 #include <QGradient>
+#include <QDebug>
 
 StatisticsModel::StatisticsModel(QObject * parent)
     : ContainerModel(KEduVocContainer::Lesson, parent)
@@ -29,7 +31,8 @@ QVariant StatisticsModel::headerData(int section, Qt::Orientation orientation, i
     if (section >= FirstDataColumn) {
         if (role == Qt::DisplayRole
             && m_doc->identifierCount() > (section - FirstDataColumn) ) {
-            return i18nc("Confidence level in language, table header", "Confidence (%1)", m_doc->identifier(section - FirstDataColumn).name());
+            return i18nc("Confidence level in language, table header", "Confidence (%1)"
+                         , m_doc->identifier(section - FirstDataColumn).name());
         }
     }
     return ContainerModel::headerData(section, orientation, role);
@@ -40,13 +43,17 @@ QVariant StatisticsModel::data(const QModelIndex & index, int role) const
     if (index.column() >= FirstDataColumn) {
         KEduVocContainer *container = static_cast<KEduVocContainer*>(index.internalPointer());
         switch (role) {
+        case LegendFractions:
+	    // Calculate the percent each grade and pregrade occupies.
+            return StatisticsLegendWidget::legendFractions(*container ,index.column() - FirstDataColumn);
         case TotalPercent: // Average grade
             return container->averageGrade(index.column() - FirstDataColumn, KEduVocContainer::Recursive);
         case TotalCount:
             return container->entryCount(KEduVocContainer::Recursive);
         default:
             if (role >= Qt::UserRole) {
-                return container->expressionsOfGrade(index.column() - FirstDataColumn, role - Grade0, KEduVocContainer::Recursive);
+                return container->expressionsOfGrade(
+                    index.column() - FirstDataColumn, role - Grade0, KEduVocContainer::Recursive);
             }
         }
     }
