@@ -16,9 +16,8 @@
 #ifndef STATISTICSMODEL_H
 #define STATISTICSMODEL_H
 
-#include "vocabulary/containermodel.h"
+#include "containermodel.h"
 
-using namespace Editor;
 
 class StatisticsModel : public ContainerModel
 {
